@@ -1,4 +1,4 @@
-from typing import List
+from typing import Coroutine, List
 
 from typing_extensions import Protocol
 
@@ -18,6 +18,9 @@ class TrioTask(Protocol):
     name: str
     child_nurseries: List["TrioNursery"]
 
+    # Internal object link to the coroutine
+    coro: Coroutine
+
 
 class TrioInstrument(Protocol):
     """Trio's instrument class to used the instrument API
